#include <klocalizedstring.h>

/********************************************************************************
** Form generated from reading UI file 'migrationwizard2.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_MIGRATIONWIZARD2_H
#define UI_MIGRATIONWIZARD2_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QTextEdit>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "ktitlewidget.h"

QT_BEGIN_NAMESPACE

class Ui_MigrationPage2
{
public:
    QVBoxLayout *verticalLayout;
    KTitleWidget *title;
    QTextEdit *_report;

    void setupUi(QWidget *MigrationPage2)
    {
        if (MigrationPage2->objectName().isEmpty())
            MigrationPage2->setObjectName(QStringLiteral("MigrationPage2"));
        MigrationPage2->resize(521, 377);
        verticalLayout = new QVBoxLayout(MigrationPage2);
        verticalLayout->setObjectName(QStringLiteral("verticalLayout"));
        title = new KTitleWidget(MigrationPage2);
        title->setObjectName(QStringLiteral("title"));

        verticalLayout->addWidget(title);

        _report = new QTextEdit(MigrationPage2);
        _report->setObjectName(QStringLiteral("_report"));
        _report->setAutoFormatting(QTextEdit::AutoBulletList);
        _report->setTabChangesFocus(true);
        _report->setUndoRedoEnabled(false);
        _report->setReadOnly(true);
        _report->setTextInteractionFlags(Qt::TextSelectableByKeyboard|Qt::TextSelectableByMouse);

        verticalLayout->addWidget(_report);


        retranslateUi(MigrationPage2);

        QMetaObject::connectSlotsByName(MigrationPage2);
    } // setupUi

    void retranslateUi(QWidget *MigrationPage2)
    {
        title->setText(tr2i18n("The KDE Wallet System", Q_NULLPTR));
        Q_UNUSED(MigrationPage2);
    } // retranslateUi

};

namespace Ui {
    class MigrationPage2: public Ui_MigrationPage2 {};
} // namespace Ui

QT_END_NAMESPACE

#endif // MIGRATIONWIZARD2_H

