#include <klocalizedstring.h>

/********************************************************************************
** Form generated from reading UI file 'kbetterthankdialogbase.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_KBETTERTHANKDIALOGBASE_H
#define UI_KBETTERTHANKDIALOGBASE_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QDialog>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>

QT_BEGIN_NAMESPACE

class Ui_KBetterThanKDialogBase
{
public:
    QGridLayout *gridLayout;
    QLabel *_label;
    QSpacerItem *spacerItem;
    QHBoxLayout *hboxLayout;
    QPushButton *_allowOnce;
    QPushButton *_allowAlways;
    QPushButton *_deny;
    QPushButton *_denyForever;
    QSpacerItem *spacerItem1;

    void setupUi(QDialog *KBetterThanKDialogBase)
    {
        if (KBetterThanKDialogBase->objectName().isEmpty())
            KBetterThanKDialogBase->setObjectName(QStringLiteral("KBetterThanKDialogBase"));
        KBetterThanKDialogBase->resize(479, 109);
        gridLayout = new QGridLayout(KBetterThanKDialogBase);
#ifndef UI_Q_OS_MAC
        gridLayout->setSpacing(6);
#endif
        gridLayout->setContentsMargins(11, 11, 11, 11);
        gridLayout->setObjectName(QStringLiteral("gridLayout"));
        _label = new QLabel(KBetterThanKDialogBase);
        _label->setObjectName(QStringLiteral("_label"));

        gridLayout->addWidget(_label, 0, 0, 1, 3);

        spacerItem = new QSpacerItem(41, 21, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout->addItem(spacerItem, 1, 2, 1, 1);

        hboxLayout = new QHBoxLayout();
#ifndef UI_Q_OS_MAC
        hboxLayout->setSpacing(6);
#endif
        hboxLayout->setContentsMargins(0, 0, 0, 0);
        hboxLayout->setObjectName(QStringLiteral("hboxLayout"));
        _allowOnce = new QPushButton(KBetterThanKDialogBase);
        _allowOnce->setObjectName(QStringLiteral("_allowOnce"));

        hboxLayout->addWidget(_allowOnce);

        _allowAlways = new QPushButton(KBetterThanKDialogBase);
        _allowAlways->setObjectName(QStringLiteral("_allowAlways"));

        hboxLayout->addWidget(_allowAlways);

        _deny = new QPushButton(KBetterThanKDialogBase);
        _deny->setObjectName(QStringLiteral("_deny"));

        hboxLayout->addWidget(_deny);

        _denyForever = new QPushButton(KBetterThanKDialogBase);
        _denyForever->setObjectName(QStringLiteral("_denyForever"));

        hboxLayout->addWidget(_denyForever);


        gridLayout->addLayout(hboxLayout, 1, 1, 1, 1);

        spacerItem1 = new QSpacerItem(61, 21, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout->addItem(spacerItem1, 1, 0, 1, 1);


        retranslateUi(KBetterThanKDialogBase);

        _allowOnce->setDefault(true);


        QMetaObject::connectSlotsByName(KBetterThanKDialogBase);
    } // setupUi

    void retranslateUi(QDialog *KBetterThanKDialogBase)
    {
        _allowOnce->setText(tr2i18n("Allow &Once", Q_NULLPTR));
        _allowAlways->setText(tr2i18n("Allow &Always", Q_NULLPTR));
        _deny->setText(tr2i18n("&Deny", Q_NULLPTR));
        _denyForever->setText(tr2i18n("Deny &Forever", Q_NULLPTR));
        Q_UNUSED(KBetterThanKDialogBase);
    } // retranslateUi

};

namespace Ui {
    class KBetterThanKDialogBase: public Ui_KBetterThanKDialogBase {};
} // namespace Ui

QT_END_NAMESPACE

#endif // KBETTERTHANKDIALOGBASE_H

