#include <klocalizedstring.h>

/********************************************************************************
** Form generated from reading UI file 'migrationwizard1.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_MIGRATIONWIZARD1_H
#define UI_MIGRATIONWIZARD1_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "ktitlewidget.h"

QT_BEGIN_NAMESPACE

class Ui_MigrationPage1
{
public:
    QVBoxLayout *verticalLayout_2;
    KTitleWidget *title;
    QLabel *label;
    QHBoxLayout *horizontalLayout;
    QSpacerItem *horizontalSpacer;
    QVBoxLayout *verticalLayout;
    QRadioButton *_optionYes;
    QRadioButton *_optionNo;
    QRadioButton *_optionNotInterested;
    QSpacerItem *horizontalSpacer_2;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *MigrationPage1)
    {
        if (MigrationPage1->objectName().isEmpty())
            MigrationPage1->setObjectName(QStringLiteral("MigrationPage1"));
        MigrationPage1->resize(523, 377);
        verticalLayout_2 = new QVBoxLayout(MigrationPage1);
        verticalLayout_2->setObjectName(QStringLiteral("verticalLayout_2"));
        title = new KTitleWidget(MigrationPage1);
        title->setObjectName(QStringLiteral("title"));

        verticalLayout_2->addWidget(title);

        label = new QLabel(MigrationPage1);
        label->setObjectName(QStringLiteral("label"));
        label->setScaledContents(true);
        label->setWordWrap(true);

        verticalLayout_2->addWidget(label);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName(QStringLiteral("horizontalLayout"));
        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);

        verticalLayout = new QVBoxLayout();
        verticalLayout->setObjectName(QStringLiteral("verticalLayout"));
        _optionYes = new QRadioButton(MigrationPage1);
        _optionYes->setObjectName(QStringLiteral("_optionYes"));
        _optionYes->setChecked(true);

        verticalLayout->addWidget(_optionYes);

        _optionNo = new QRadioButton(MigrationPage1);
        _optionNo->setObjectName(QStringLiteral("_optionNo"));

        verticalLayout->addWidget(_optionNo);

        _optionNotInterested = new QRadioButton(MigrationPage1);
        _optionNotInterested->setObjectName(QStringLiteral("_optionNotInterested"));

        verticalLayout->addWidget(_optionNotInterested);


        horizontalLayout->addLayout(verticalLayout);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout->addItem(horizontalSpacer_2);


        verticalLayout_2->addLayout(horizontalLayout);

        verticalSpacer = new QSpacerItem(20, 102, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout_2->addItem(verticalSpacer);


        retranslateUi(MigrationPage1);

        QMetaObject::connectSlotsByName(MigrationPage1);
    } // setupUi

    void retranslateUi(QWidget *MigrationPage1)
    {
        title->setText(tr2i18n("The KDE Wallet System", Q_NULLPTR));
        label->setText(tr2i18n("Congratulations! The system detected that you're running the latest version of the KWallet, using KDE Frameworks 5.\n"
"\n"
"It seems that you also have KDE4 wallet(s) on your system.\n"
"\n"
"Would you like them to be migrated to this new KWallet version? The operation will only take one minute to be performed.\n"
"", Q_NULLPTR));
        _optionYes->setText(tr2i18n("&Yes, migrate my wallets now.", Q_NULLPTR));
        _optionNo->setText(tr2i18n("No, I'd rather do this upon ne&xt session start,\n"
"and I'll cancel this wizard for now.", Q_NULLPTR));
        _optionNotInterested->setText(tr2i18n("No, and p&lease do not prompt me again.", Q_NULLPTR));
        Q_UNUSED(MigrationPage1);
    } // retranslateUi

};

namespace Ui {
    class MigrationPage1: public Ui_MigrationPage1 {};
} // namespace Ui

QT_END_NAMESPACE

#endif // MIGRATIONWIZARD1_H

